=========
PyTimings
=========


.. image:: https://img.shields.io/pypi/v/pytimings.svg
        :target: https://pypi.python.org/pypi/pytimings

.. image:: https://github.com/WWU-AMM/pytimings/workflows/pytest/badge.svg
        :target: https://github.com/WWU-AMM/pytimings/actions

.. image:: https://readthedocs.org/projects/pytimings/badge/?version=latest
        :target: https://pytimings.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




MPI Aware section timings


* Free software: BSD license
* Documentation: https://pytimings.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
